# eric7.DocumentationTools.TemplatesListsStyle

Module implementing templates for the documentation generator (lists style).

### Global Attributes

authorInfoTemplate
classTemplate
constructorTemplate
deprecatedTemplate
eventsListEntryTemplate
eventsListTemplate
exceptionsListEntryTemplate
exceptionsListTemplate
footerTemplate
functionTemplate
headerTemplate
indexBodyTemplate
indexListEntryTemplate
indexListModulesTemplate
indexListPackagesTemplate
listEntryDeprecatedTemplate
listEntryNoneTemplate
listEntrySimpleTemplate
listEntryTemplate
listTemplate
methodTemplate
moduleTemplate
paragraphTemplate
parameterTypesListEntryTemplate
parametersListEntryTemplate
parametersListTemplate
rbFileTemplate
rbModuleTemplate
rbModulesClassTemplate
returnTypesTemplate
returnsTemplate
seeLinkTemplate
seeListEntryTemplate
seeListTemplate
signalsListEntryTemplate
signalsListTemplate
sinceInfoTemplate
yieldTypesTemplate
yieldsTemplate

### Classes

None

### Functions

None